import { _ as _objectWithoutPropertiesLoose, m as moment, g as getValue, d as datetime } from './index.esm2.js';
import { useState } from 'react';
import { DatePicker } from '@mui/x-date-pickers/DatePicker';
import { AdapterDateFns } from '@mui/x-date-pickers/AdapterDateFns';
import { LocalizationProvider } from '@mui/x-date-pickers/LocalizationProvider';
import { TimePicker } from '@mui/x-date-pickers/TimePicker';
import { DateTimePicker } from '@mui/x-date-pickers/DateTimePicker';
import { DesktopDatePicker } from '@mui/x-date-pickers/DesktopDatePicker';
import { MobileDatePicker } from '@mui/x-date-pickers/MobileDatePicker';
import { TextField } from '@mui/material';
import { jsxs, jsx } from 'react/jsx-runtime';
import '@qubejs/core';
import 'prop-types';
import '@mui/material/Button';
import '@mui/material/IconButton';
import '@mui/material/Typography';
import '@mui/material/Dialog';
import '@mui/material/DialogTitle';
import '@mui/material/DialogActions';
import '@mui/material/DialogContent';
import '@mui/material/Slide';
import '@mui/material/LinearProgress';
import '@mui/material/CircularProgress';
import '@mui/icons-material/SelectAll';
import '@mui/lab/Alert';
import '@mui/lab/AlertTitle';
import '@mui/material/Autocomplete';
import '@mui/material/Chip';
import '@mui/material/Box';
import '@mui/material/TextField';
import '@mui/material/BottomNavigation';
import '@mui/material/BottomNavigationAction';
import '@mui/material/Breadcrumbs';
import '@mui/icons-material/NavigateNext';
import '@mui/material/ButtonGroup';
import '@mui/material/Tooltip';
import '@mui/material/FormLabel';
import '@mui/material/FormControl';
import '@mui/material/FormControlLabel';
import '@mui/material/Checkbox';
import '@mui/material/FormGroup';
import '@mui/material/FormHelperText';
import '@mui/material/Menu';
import '@mui/material/MenuItem';
import '@mui/material/ListItemIcon';
import '@mui/material/Divider';
import '@mui/material/List';
import '@mui/material/ListItem';
import '@mui/material/ListItemButton';
import '@mui/material/ListItemText';
import '@mui/material/Collapse';
import '@mui/material/Avatar';
import '@mui/material/Select';
import '@mui/material/OutlinedInput';
import '@mui/material/Input';
import '@mui/material/InputLabel';
import '@mui/material/Pagination';
import '@mui/material/Radio';
import '@mui/material/RadioGroup';
import 'react-google-recaptcha';
import '@mui/material/Skeleton';
import '@mui/material/Snackbar';
import '@mui/icons-material/Close';
import '@mui/material/Switch';
import '@mui/material/Tabs';
import '@mui/material/Tab';
import 'react-dom';
import 'react-router-dom';
import '@mui/lab/TreeView';
import '@mui/icons-material/ExpandMore';
import '@mui/icons-material/ChevronRight';
import '@mui/lab/TreeItem';

const _excluded = ["value", "label", "disabled", "readOnly", "helperText", "inputVariant", "className", "valueFormat", "minDate", "maxDate", "onChange", "error", "errorMessage", "instanceType", "row"];
const instanceTypes = {
  DatePicker,
  TimePicker,
  DateTimePicker,
  DesktopDatePicker,
  MobileDatePicker
};
const instanceDefaultValues = {
  DatePicker: {
    inputFormat: 'MM/dd/yyyy',
    outputFormat: 'MM/DD/YYYY',
    mask: '__/__/____'
  },
  DateTimePicker: {
    inputFormat: 'MM/dd/yyyy HH:mm',
    outputFormat: 'MM/DD/YYYY HH:mm',
    mask: '__/__/____ __:__'
  },
  TimePicker: {
    inputFormat: 'HH:mm',
    outputFormat: 'HH:mm',
    mask: '__:__'
  }
};
const DateSelector = _ref => {
  let {
      value,
      label = '',
      disabled,
      readOnly,
      helperText,
      inputVariant = 'outlined',
      className = '',
      valueFormat,
      minDate,
      maxDate,
      onChange,
      error,
      errorMessage,
      instanceType = 'DatePicker',
      row
    } = _ref,
    rest = _objectWithoutPropertiesLoose(_ref, _excluded);
  const isValid = value ? moment(value).isValid() : false;
  const valueDate = isValid ? moment(value)._d : value;
  const [focus, setFocus] = useState(false);
  const {
    inputFormat = 'MM/dd/yyyy',
    outputFormat = 'MM/DD/YYYY',
    mask = '__/__/____'
  } = instanceDefaultValues[instanceType] || rest;
  const handleonSelect = (date, input) => {
    if (!input && date && moment(date).isValid()) {
      const text = moment(date).format(outputFormat);
      onChange && onChange({
        value: !valueFormat ? moment(date).toISOString() : moment(date).format(valueFormat),
        text
      });
    } else if (input) {
      const valueToPass = moment(input, outputFormat, true).isValid() ? !valueFormat ? moment(input).toISOString() : moment(input).format(valueFormat) : null;
      onChange && onChange({
        value: valueToPass,
        text: input
      });
    } else {
      onChange && onChange({
        value: undefined,
        text: ''
      });
    }
  };
  const handleOnFocus = () => {
    setFocus(true);
  };
  const handleOnBlur = () => {
    setFocus(false);
  };
  const finalMinDate = getValue(undefined, minDate, row);
  const finalMaxDate = getValue(undefined, maxDate, row);
  const extraProps = {};
  if (finalMinDate) {
    extraProps.minDate = typeof finalMinDate === 'string' ? datetime.new(finalMinDate)._date._d : finalMinDate;
  }
  if (finalMaxDate) {
    extraProps.maxDate = typeof finalMaxDate === 'string' ? datetime.new(finalMaxDate)._date._d : finalMaxDate;
  }
  const DatePickerInstance = instanceTypes[instanceType];
  return /*#__PURE__*/jsxs("div", {
    className: `sq-date-selector ${className}`,
    children: [/*#__PURE__*/jsx(LocalizationProvider, {
      dateAdapter: AdapterDateFns,
      children: /*#__PURE__*/jsx(DatePickerInstance, Object.assign({}, rest, {
        inputFormat: inputFormat,
        disabled: disabled
      }, extraProps, {
        PopperProps: {
          className: 'sq-date-selector__dialog'
        },
        DialogProps: {
          classes: {
            root: 'sq-date-selector__dialog'
          }
        },
        mask: mask,
        value: isValid ? valueDate || null : null,
        renderInput: props => /*#__PURE__*/jsx(TextField, Object.assign({}, props, {
          label: label,
          error: error,
          variant: inputVariant,
          readOnly: readOnly,
          helperText: helperText
        })),
        onChange: handleonSelect,
        onFocus: handleOnFocus,
        onBlur: handleOnBlur
      }))
    }), !focus && errorMessage && /*#__PURE__*/jsx("div", {
      className: "sq-error",
      children: errorMessage
    })]
  });
};
DateSelector.propTypes = {};

export { DateSelector as default };
